@@ -5,7 +5,7 @@ use warnings;
 package Dist::Zilla::Plugin::Meta::Contributors;
 # ABSTRACT: Generate an x_contributors section in distribution metadata
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moose;
 
@@ -48,7 +48,7 @@ Dist::Zilla::Plugin::Meta::Contributors - Generate an x_contributors section in
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -100,12 +100,22 @@ L<https://github.com/dagolden/Dist-Zilla-Plugin-Meta-Contributors>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge
+=for stopwords David Golden Karen Etheridge
+
+=over 4
+
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
 
 Karen Etheridge <ether@cpan.org>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
